@@ -2,22 +2,20 @@
 # this repository contains the full copyright notices and license terms.
 import datetime
 import logging
-
-from decimal import Decimal, ROUND_HALF_EVEN, localcontext
+from decimal import ROUND_HALF_EVEN, Decimal, localcontext
 
 from dateutil.relativedelta import relativedelta
-
 from sql import Window
 from sql.functions import NthValue
 
 from trytond.i18n import gettext
 from trytond.model import (
-    ModelView, ModelSQL, DeactivableMixin, fields, Unique, Check, SymbolMixin,
-    DigitsMixin)
-from trytond.transaction import Transaction
+    Check, DeactivableMixin, DigitsMixin, ModelSQL, ModelView, SymbolMixin,
+    Unique, fields)
 from trytond.pool import Pool
-from trytond.rpc import RPC
 from trytond.pyson import Eval, If
+from trytond.rpc import RPC
+from trytond.transaction import Transaction
 
 from .ecb import RatesNotAvailableError, get_rates
 from .exceptions import RateError
@@ -44,7 +42,7 @@ class Currency(
     rates = fields.One2Many('currency.currency.rate', 'currency', 'Rates',
         help="Add floating exchange rates for the currency.")
     rounding = fields.Numeric('Rounding factor', required=True,
-        digits=(12, Eval('digits', 6)), depends=['digits'],
+        digits=(12, Eval('digits', 6)),
         help="The minimum amount which can be represented in this currency.")
     digits = fields.Integer("Digits", required=True,
         help="The number of digits to display after the decimal separator.")
@@ -310,8 +308,7 @@ class Cron(ModelSQL, ModelView):
         states={
             'required': Eval('frequency') == 'weekly',
             'invisible': Eval('frequency') != 'weekly',
-            },
-        depends=['frequency'])
+            })
     day = fields.Integer(
         "Day of Month",
         domain=[If(Eval('frequency') == 'monthly',
@@ -321,8 +318,7 @@ class Cron(ModelSQL, ModelView):
         states={
             'required': Eval('frequency') == 'monthly',
             'invisible': Eval('frequency') != 'monthly',
-            },
-        depends=['frequency'])
+            })
     currency = fields.Many2One(
         'currency.currency', "Currency", required=True,
         help="The base currency to fetch rate.")
